# swaystatus

Generate a status line for [swaybar][swaybar-protocol].

## Installation

### Python

Install as a python package:

```sh
pip install swaystatus
```

### Arch User Repository (AUR)

There are two packages available for Arch Linux, available via the
AUR.

Stable, based on the latest tagged release:
[swaystatus][aur]

Unstable, based on the latest commit to the main branch:
[swaystatus-git][aur-git]

## Testing

To run the included tests:

```sh
pytest
```

[swaybar-protocol]: https://man.archlinux.org/man/swaybar-protocol.7
[aur]: https://aur.archlinux.org/packages/swaystatus/
[aur-git]: https://aur.archlinux.org/packages/swaystatus-git/
